import click

from dtuhpc.cli.cli_config import CLIConfig
from dtuhpc.commands import BQueues


@click.command()
@click.pass_obj
def bqueues(config: CLIConfig):
    """Show current running jobs."""
    conn = config.connection()

    cmd = BQueues(conn)
    cmd.run()
    conn.close()



from .option import Option


class CoreBlockSizeOption(Option):
    block_size: int

    def __init__(self, block_size: int):
        assert block_size > 0
        self.block_size = block_size

        super().__init__(option="R", value=f"span[block={block_size}]")



from typing import Optional

from .option import Option


class UseGPUOption(Option):
    num_of_gpus: int
    per_task: bool
    mode: str
    aff: bool
    block: bool
    gpu_model_name: Optional[str]
    memory_size: Optional[int]

    def __init__(
        self,
        num_of_gpus: int = 1,
        per_task: bool = False,
        mode: str = "exclusive_process",
        aff: bool = True,
        block: bool = False,
        gpu_model_name: Optional[str] = None,
        memory_size: Optional[int] = None,
    ):
        self.num_of_gpus = num_of_gpus
        self.per_task = per_task
        self.mode = mode
        self.aff = aff
        self.block = block
        self.gpu_model_name = gpu_model_name
        self.memory_size = memory_size

        super().__init__(option="gpu", value=self.format_value())

    @staticmethod
    def format_bool_as_yes_no(boolvar):
        return "yes" if boolvar else "no"

    def format_value(self):
        options = [
            f"num={self.num_of_gpus}"
            if self.per_task is False
            else f"num={self.num_of_gpus}/task",
            f"mode={self.mode}",
            f"aff={self.format_bool_as_yes_no(self.aff)}",
            f"block={self.format_bool_as_yes_no(self.block)}",
        ]

        if self.gpu_model_name is not None:
            options.append(f"gmodel={self.gpu_model_name}")

        if self.memory_size is not None:
            options.append(f"gmem={self.memory_size}G")

        return "[" + ":".join(options) + "]"



from .option import Option


class EmailForNotificationsOption(Option):
    email: str

    def __init__(self, email: str):
        self.email = email
        super().__init__(option="u", value=email)



import click

from dtuhpc.cli.cli_config import CLIConfig


@click.command()
@click.pass_obj
def ssh(config: CLIConfig):
    """SSH into DTU's server."""
    config.load_config()
    conn = config.connection()
    conn.open_shell()
    conn.close()



from typing import Optional

import click

from dtuhpc.cli.cli_config import CLIConfig
from dtuhpc.commands import BStat


@click.command()
@click.option("--cpu", "-c", default=False, help="Show CPU usage.")
@click.option("--memory", "-m", default=False, help="Show memory usage.")
@click.option("--user", "-u", default=None, type=str)
@click.option("--queue", "-q", default=None, type=str)
@click.argument("job_ids", nargs=-1)
@click.pass_obj
def bstat(
    config: CLIConfig,
    cpu: bool,
    memory: bool,
    user: Optional[str],
    queue: Optional[str],
    job_ids: list[str],
):
    """Show current running jobs."""
    conn = config.connection()

    cmd = BStat(conn)
    cmd.run(
        *job_ids,
        cpu_usage=cpu,
        memory_usage=memory,
        user=user,
        queue=queue,
    )
    conn.close()



import click

from dtuhpc.cli.cli_config import CLIConfig
from dtuhpc.commands import Showstart


@click.command()
@click.option("--user", "-u", default=None, type=str)
@click.option("--queue", "-q", default=None, type=str)
@click.argument("job_ids", nargs=-1)
@click.pass_obj
def showstart(config: CLIConfig, user, queue, job_ids):
    """Show start times for jobs."""
    conn = config.connection()

    cmd = Showstart(conn)
    cmd.run(*job_ids, user=user, queue=queue)
    conn.close()
